==> r2e_test_server-0.1.3.tar.gz: r2e_test_server-0.1.3/r2e_test_server/ast/transformer.py <==
import ast


class ASTTransformer(ast.NodeTransformer):
    """Base class for AST transformer."""

    def __init__(self, tree: ast.Module):
        self.tree = tree

    def transform(self):
        return super().visit(self.tree)


class ImportAliasReplacer(ASTTransformer):
    """Replace aliases of imports with original name in the code.

    Args:
        tree (ast.Module): AST tree of the code.
        names (list[str]): list of original names to be used in the code.
    """

    def __init__(self, tree: ast.Module, names: list[str]):
        super().__init__(tree)
        self.aliases = self.get_all_aliases(names)

    def get_all_aliases(self, names: list[str]) -> dict:
        aliases = {}
        for node in self.tree.body:
            if isinstance(node, (ast.Import, ast.ImportFrom)):
                for alias in node.names:

                    # if alias is used and it is not same as name
                    if alias.asname and alias.asname not in names:

                        # replace alias with name itself
                        if alias.name in names:
                            aliases[alias.asname] = alias.name

        return aliases

    def visit_Name(self, node):
        if node.id in self.aliases:
            return ast.copy_location(
                ast.Name(id=self.aliases[node.id], ctx=node.ctx), node
            )
        return node


class NameReplacer(ASTTransformer):
    """Replace old name with new name in the code

    Args:
        tree (ast.Module): AST tree of the code.
        old_name (str): the name to be replaced
        new_name (str): the name to replace with
    """

    def __init__(self, tree: ast.Module, old_name: str, new_name: str):
        super().__init__(tree)
        self.old_name = old_name
        self.new_name = new_name

    def visit_Name(self, node):
        if node.id == self.old_name:
            return ast.copy_location(ast.Name(id=self.new_name, ctx=node.ctx), node)
        return node


class RemoveFunctionTransformer(ASTTransformer):
    """Remove a function from the code.

    Args:
        tree (ast.Module): AST tree of the code.
        function_name (str): the name of the function to remove
    """

    def __init__(self, tree: ast.Module, function_name: str):
        super().__init__(tree)
        self.function_name = function_name

    def visit_FunctionDef(self, node):
        if node.name == self.function_name:
            # Remove the function by returning None
            return None
        return node


# import ast


class RemoveLastNodeTransformer(ASTTransformer):
    """Remove the last ast node from code.

    Args:
        tree (ast.Module): AST tree of the code.
    """

    def __init__(self, tree: ast.Module):
        super().__init__(tree)

    def visit_Module(self, node):

        if isinstance(node.body[-1], ast.ClassDef):
            if len(node.body[-1].body) == 1:
                node.body.pop()
            else:
                node.body[-1].body.pop()
        else:
            node.body.pop()

        return node

==> r2e_test_server-0.1.4.tar.gz: r2e_test_server-0.1.4/r2e_test_server/ast/transformer.py <==
import ast
from typing import List


class ASTTransformer(ast.NodeTransformer):
    """Base class for AST transformer."""

    def __init__(self, tree: ast.Module):
        self.tree = tree

    def transform(self):
        return super().visit(self.tree)


class ImportAliasReplacer(ASTTransformer):
    """Replace aliases of imports with original name in the code.

    Args:
        tree (ast.Module): AST tree of the code.
        names (List[str]): list of original names to be used in the code.
    """

    def __init__(self, tree: ast.Module, names: List[str]):
        super().__init__(tree)
        self.aliases = self.get_all_aliases(names)

    def get_all_aliases(self, names: List[str]) -> dict:
        aliases = {}
        for node in self.tree.body:
            if isinstance(node, (ast.Import, ast.ImportFrom)):
                for alias in node.names:

                    # if alias is used and it is not same as name
                    if alias.asname and alias.asname not in names:

                        # replace alias with name itself
                        if alias.name in names:
                            aliases[alias.asname] = alias.name

        return aliases

    def visit_Name(self, node):
        if node.id in self.aliases:
            return ast.copy_location(
                ast.Name(id=self.aliases[node.id], ctx=node.ctx), node
            )
        return node


class NameReplacer(ASTTransformer):
    """Replace old name with new name in the code

    Args:
        tree (ast.Module): AST tree of the code.
        old_name (str): the name to be replaced
        new_name (str): the name to replace with
    """

    def __init__(self, tree: ast.Module, old_name: str, new_name: str):
        super().__init__(tree)
        self.old_name = old_name
        self.new_name = new_name

    def visit_Name(self, node):
        if node.id == self.old_name:
            return ast.copy_location(ast.Name(id=self.new_name, ctx=node.ctx), node)
        return node


class RemoveFunctionTransformer(ASTTransformer):
    """Remove a function from the code.

    Args:
        tree (ast.Module): AST tree of the code.
        function_name (str): the name of the function to remove
    """

    def __init__(self, tree: ast.Module, function_name: str):
        super().__init__(tree)
        self.function_name = function_name

    def visit_FunctionDef(self, node):
        if node.name == self.function_name:
            # Remove the function by returning None
            return None
        return node


# import ast


class RemoveLastNodeTransformer(ASTTransformer):
    """Remove the last ast node from code.

    Args:
        tree (ast.Module): AST tree of the code.
    """

    def __init__(self, tree: ast.Module):
        super().__init__(tree)

    def visit_Module(self, node):

        if isinstance(node.body[-1], ast.ClassDef):
            if len(node.body[-1].body) == 1:
                node.body.pop()
            else:
                node.body[-1].body.pop()
        else:
            node.body.pop()

        return node
